@@ -204,6 +204,7 @@ async def main() -> None:
                 # region #-- get the online devices: format = name (ip) --#
                 if args.get_online_devices or all_args:
                     _LOGGER.debug("Preparing online devices")
+                    adapter: dict
                     device: Device
                     section = "Online Devices"
                     section += f"\n{'-' * len(section)}\n"
@@ -234,7 +235,7 @@ async def main() -> None:
                     sections.append(section)
                 # endregion
             elif args.target == "node":
-                _node: List = [node for node in _mesh.nodes if node.name.lower() == args.name.lower()]
+                _node: List[Node] = [node for node in _mesh.nodes if node.name.lower() == args.name.lower()]
                 if not _node:
                     node_names = [node.name for node in _mesh.nodes]
                     args_parser.error(f"Invalid node name ({args.name}). Must be one of {node_names}")
@@ -293,12 +294,12 @@ async def main() -> None:
                         _LOGGER.debug("Preparing node connected devices")
                         section = "Connected Devices"
                         section += f"\n{'-' * len(section)}\n"
-                        device: dict
-                        for device in _node.connected_devices:
-                            section += f"{device.get('name')} " \
-                                       f"({device.get('ip')}) " \
-                                       f"({device.get('type')}) " \
-                                       f"({device.get('guest_network')})\n"
+                        d: dict
+                        for d in _node.connected_devices:
+                            section += f"{d.get('name')} " \
+                                       f"({d.get('ip')}) " \
+                                       f"({d.get('type')}) " \
+                                       f"({d.get('guest_network')})\n"
                         sections.append(section.rstrip("\n"))
                     # endregion
             elif args.target == "device":
